@@ -145,7 +145,7 @@ impl Gusto {
             ("client_secret", &self.client_secret),
         ];
         let client = reqwest::Client::new();
-        let resp = client.post(&format!("{}oauth/token", ENDPOINT)).headers(headers).form(&params).send().await.unwrap();
+        let resp = client.post(&format!("{}oauth/token", ENDPOINT)).headers(headers).query(&params).send().await.unwrap();
 
         // Unwrap the response.
         let t: AccessToken = resp.json().await.unwrap();
@@ -168,7 +168,7 @@ impl Gusto {
             ("client_secret", &self.client_secret),
         ];
         let client = reqwest::Client::new();
-        let resp = client.post(&format!("{}oauth/token", ENDPOINT)).headers(headers).form(&params).send().await.unwrap();
+        let resp = client.post(&format!("{}oauth/token", ENDPOINT)).headers(headers).query(&params).send().await.unwrap();
 
         // Unwrap the response.
         let t: AccessToken = resp.json().await.unwrap();
